@@ -18,8 +18,10 @@ EMAIL_PASSWORD = os.environ.get('CL_EMAIL_PASS')
 # WEBHOOK (optional) configures the discord webhook url to send summary to
 WEBHOOK = os.environ.get('DISCORD_WEBHOOK')
 
-# MAX_POST_DAYS configures the maximum number of days old a post can be active for before it is reposted 
+# MAX_POST_DAYS configures the maximum number of days after posting before reposting 
 MAX_POST_DAYS = 11
+# MAX_REPOSTS configures the maximum number of posts to repost per run
+MAX_REPOSTS = 3
 
 # IMAP_SERVER for email provider, default for gmail
 IMAP_SERVER = 'imap.gmail.com'
@@ -63,7 +65,7 @@ cl.set_home_window()
 active_posts = cl.get_posts()
 
 # Loop through active posts and repost if older than MAX_POST_DAYS
-for post in active_posts:
+for post in active_posts[:MAX_REPOSTS]:
     # parse_date converts string from dd MTH yyyy HH:MM format to datetime object
     def parse_date(string):    
         date = string.split(' ')
